@@ -8,7 +8,7 @@ from pytest import raises
 # noinspection PyProtectedMember
 from tsetmc import Instrument, _core, get_market_watch_init, \
     get_closing_price_all, get_client_type_all, get_key_stats
-from tsetmc._core import parse_index
+from tsetmc._core import _parse_index
 
 
 def patch_get_content(name):
@@ -31,22 +31,27 @@ def test_get_page_info():
     trade_history = d.pop('trade_history')
     related_companies = d.pop('related_companies')
     assert d == {
-        'tmax': 19820.0
-        , 'tmin': 21900.0
-        , 'bvol': 5479452
-        , 'eps': 1639
-        , 'free_float': 33
-        , 'l30': 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c'  # todo
-        , 'sector_name': 'فلزات اساسی'
-        , 'market': 'بازار اول (تابلوی اصلی) بورس'
-        , 'month_average_volume': 98322903
-        , 'l18': 'فملی'
-        , 'sector_pe': 15.4
-        , 'z': 101400000000
-        , 'week_max': 22000.0
-        , 'week_min': 20010.0
-        , 'year_max': 39810.0
-        , 'year_min': 5181.0}
+        'bvol': 5479452,
+        'cisin': 'IRO1MSMI0000',
+        'cs': 27,
+        'eps': 1639,
+        'flow': 1,
+        'free_float': 33,
+        'group_code': 'N1',
+        'isin': 'IRO1MSMI0001',
+        'l18': 'فملی',
+        'l30': 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c',
+        'market': 'بازار اول (تابلوی اصلی) بورس',
+        'month_average_volume': 98322903,
+        'sector_name': 'فلزات اساسی',
+        'sector_pe': 15.4,
+        'tmax': 21900.0,
+        'tmin': 19820.0,
+        'week_max': 22000.0,
+        'week_min': 20010.0,
+        'year_max': 39810.0,
+        'year_min': 5181.0,
+        'z': 101400000000}
     assert related_companies == [
             [46348559193224090, 'فولاد', 'فولاد مبارکه اصفهان']
             , [35425587644337450, 'فملی', 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c']
@@ -112,55 +117,67 @@ def test_get_page_info():
 @patch_get_content('dey.html')
 def test_get_page_info_no_free_float():
     d = Instrument(1).get_page_info()
-    assert d.items() >= {
-        'tmax': 43722.0
-        , 'tmin': 48324.0
-        , 'bvol': 2231446
-        , 'eps': 4326
-        , 'free_float': None
-        , 'l30': 'بانک دی'
-        , 'sector_name': 'بانکها و موسسات اعتباری'
-        , 'market': 'بازار دوم فرابورس'
-        , 'month_average_volume': 25836324
-        , 'l18': 'دی'
-        , 'sector_pe': 16.69
-        , 'z': 6400000000
-        , 'week_max': 49934.0
-        , 'week_min': 43722.0
-        , 'year_max': 83000.0
-        , 'year_min': 2674.0
-    }.items()
+    d.pop('related_companies')  # too long
+    d.pop('trade_history')  # too long
+    assert d == {
+        'bvol': 2231446,
+        'cisin': 'IRO3BDYZ0003',
+        'cs': 57,
+        'eps': 4326,
+        'flow': 2,
+        'free_float': None,
+        'group_code': 'Z1',
+        'isin': 'IRO3BDYZ0001',
+        'l18': 'دی',
+        'l30': 'بانک دی',
+        'market': 'بازار دوم فرابورس',
+        'month_average_volume': 25836324,
+        'sector_name': 'بانکها و موسسات اعتباری',
+        'sector_pe': 16.69,
+        'tmax': 48324.0,
+        'tmin': 43722.0,
+        'week_max': 49934.0,
+        'week_min': 43722.0,
+        'year_max': 83000.0,
+        'year_min': 2674.0,
+        'z': 6400000000}
 
 
 @patch_get_content('kala.html')
 def test_get_page_info_no_eps():
     d = Instrument(1).get_page_info()
-    assert d.items() >= {
-        'tmax': 37970.0
-        , 'tmin': 41950.0
-        , 'bvol': 1306165
-        , 'eps': None
-        , 'free_float': 100
-        , 'l30': 'بورس کالای ایران'
-        , 'sector_name': 'فعالیتهای کمکی به نهادهای مالی واسط'
-        , 'market': 'بازار اول (تابلوی فرعی) بورس'
-        , 'month_average_volume': 5720005
-        , 'l18': 'کالا'
-        , 'sector_pe': 26.22
-        , 'z': 2500000000
-        , 'week_max': 46870.0
-        , 'week_min': 37970.0
-        , 'year_max': 105352.0
-        , 'year_min': 12376.0
-    }.items()
+    d.pop('related_companies')  # too long
+    d.pop('trade_history')  # too long
+    assert d == {
+        'bvol': 1306165,
+        'cisin': 'IRO1KALA0001',
+        'cs': 67,
+        'eps': None,
+        'flow': 1,
+        'free_float': 100,
+        'group_code': 'N1',
+        'isin': 'IRO1KALA0001',
+        'l18': 'کالا',
+        'l30': 'بورس کالای ایران',
+        'market': 'بازار اول (تابلوی فرعی) بورس',
+        'month_average_volume': 5720005,
+        'sector_name': 'فعالیتهای کمکی به نهادهای مالی واسط',
+        'sector_pe': 26.22,
+        'tmax': 41950.0,
+        'tmin': 37970.0,
+        'week_max': 46870.0,
+        'week_min': 37970.0,
+        'year_max': 105352.0,
+        'year_min': 12376.0,
+        'z': 2500000000}
 
 
 @patch_get_content('khgostar.html')
 def test_get_page_info_no_sector_pe():
     d = Instrument(1).get_page_info()
     assert d.items() >= {
-        'tmax': 3670.0
-        , 'tmin': 4050.0
+        'tmin': 3670.0
+        , 'tmax': 4050.0
         , 'bvol': 15842055
         , 'eps': 450
         , 'free_float': 52
@@ -516,7 +533,7 @@ def test_parse_index():
         'tse_tval': 34288551133025.0,
         'tse_tvol': 3055466451.0,
         'tse_value': 4.674381234630472e+16
-    } == parse_index(
+    } == _parse_index(
         "99/12/16 15:45:46,F,1169760.86,<div class='mn'>(8155.90)</div> -0.69%,46743812346304720.00,3055466451.00,34288551133025.00,428601,N,1057924358.00,163701347122693.00,342228,N,101096.00,31470939000.00,2621,")
 
     assert {
@@ -536,5 +553,5 @@ def test_parse_index():
         'tse_tno': 75828635544957.0,
         'tse_tval': 75828635544957.0,
         'tse_tvol': 9682732949.0,
-        'tse_value': 4.973605456635374e+16} == parse_index(
+        'tse_value': 4.973605456635374e+16} == _parse_index(
         "99/12/24 14:39:40,F,1245186.04,<div class='pn'>15808.56</div> 1.29%,49736054566353740.00,9682732949.00,75828635544957.00,830860,F,1577202926.00,128484547655014.00,544617,F,225866.00,57759844000.00,5796,")
