@@ -19,17 +19,42 @@ GET = Session().get
 
 FARSI_NORM = ''.maketrans('يك', 'یک')
 F = r'(-?\d+(?:\.\d+)?)'  # float pattern
-SECTOR_PE_SEARCH = rc(rf"SectorPE='{F}'").search
-TITLE_SEARCH = rc(r"Title='(.*?) \((.*?)\) \- ([^']*)'").search
-FREE_FLOAT_SEARCH = rc(rf"KAjCapValCpsIdx='{F}'").search
-GROUP_NAME_SEARCH = rc(r"LSecVal='(.*?)'").search
-BASE_VOLUME_SEARCH = rc(r"BaseVol=(\d+)").search
-EPS_SEARCH = rc(r"EstimatedEPS='(\d+)'").search
-SHARES_SEARCH = rc(r'ZTitad=(\d+)').search
-ALLOWED_MIN_MAX_SEARCH = rc(rf"PSGelStaMax='{F}',PSGelStaMin='{F}").search
-WEAK_YEAR_MIN_MAX_SEARCH = rc(
-    rf"MinWeek='{F}',MaxWeek='{F}',MinYear='{F}',MaxYear='{F}'").search
-MONTH_AVG_VOL_SEARCH = rc(r"QTotTran5JAvg='(\d+)'").search
+# This regex is generated using page_vars_regex_generator.py.
+# Fix and update that script before making changes this regex.
+PAGE_VARS = rc(
+    "TopInst='(?P<TopInst>[^,]*)',"
+    "LVal18AFC='[^,]*',"
+    "DEven='(?P<DEven>[^,]*)',"
+    "LSecVal='(?P<LSecVal>[^,]*)',"
+    "CgrValCot='(?P<CgrValCot>[^,]*)',"
+    "Flow='(?P<Flow>[^,]*)',"
+    "InstrumentID='(?P<InstrumentID>[^,]*)',"
+    "InsCode='(?P<InsCode>[^,]*)',"
+    'BaseVol=(?P<BaseVol>[^,]*),'
+    "EstimatedEPS='(?P<EstimatedEPS>[^,]*)',"
+    'ZTitad=(?P<ZTitad>[^,]*),'
+    "CIsin='(?P<CIsin>[^,]*)',"
+    "LVal18AFC='(?P<LVal18AFC>[^,]*)',"
+    "CSecVal='(?P<CSecVal>[^,]*)',"
+    "PdrCotVal='(?P<PdrCotVal>[^,]*)',"
+    "PClosing='(?P<PClosing>[^,]*)',"
+    "PSGelStaMax='(?P<PSGelStaMax>[^,]*)',"
+    "PSGelStaMin='(?P<PSGelStaMin>[^,]*)',"
+    "Title='(?P<Title>[^,]*)',"
+    "FaraDesc ='(?P<FaraDesc>[^,]*)',"
+    "MinWeek='(?P<MinWeek>[^,]*)',"
+    "MaxWeek='(?P<MaxWeek>[^,]*)',"
+    "MinYear='(?P<MinYear>[^,]*)',"
+    "MaxYear='(?P<MaxYear>[^,]*)',"
+    "QTotTran5JAvg='(?P<QTotTran5JAvg>[^,]*)',"
+    "SectorPE='(?P<SectorPE>[^,]*)',"
+    "KAjCapValCpsIdx='(?P<KAjCapValCpsIdx>[^,]*)',"
+    'PriceMin=(?P<PriceMin>[^,]*),'
+    'PriceMax=(?P<PriceMax>[^,]*),'
+    'PriceYesterday=(?P<PriceYesterday>[^;]*);'
+    "ThemeCount='(?P<ThemeCount>[^;]*)';"
+).search
+TITLE_FULLMATCH = rc(r"(.*?) \(.*?\) \- ([^']*)").fullmatch
 RELATED_COMPANIES = rc(r"var RelatedCompanies=(\[.*\]);").search
 TRADE_HISTORY = rc(r"var TradeHistory=(\[.*\]);").search
 STR_TO_NUM = partial(rc(rf"'{F}'").sub, r'\1')
@@ -83,37 +108,39 @@ class Instrument:
             https://cdn.tsetmc.com/Site.aspx?ParTree=151713
         """
         text = fa_norm_text(f'http://tsetmc.com/Loader.aspx?ParTree=151311&i={self.id}')
-        t_min_max = ALLOWED_MIN_MAX_SEARCH(text)
-        wy_min_max = WEAK_YEAR_MIN_MAX_SEARCH(text)
-        title_match = TITLE_SEARCH(text)
-        free_float_match = FREE_FLOAT_SEARCH(text)
-        eps_match = EPS_SEARCH(text)
-        sector_pe_match = SECTOR_PE_SEARCH(text)
+        m = PAGE_VARS(text)
+        title_match = TITLE_FULLMATCH(m['Title'])
+        free_float = m['KAjCapValCpsIdx']
+        eps = m['EstimatedEPS']
+        sector_pe = m['SectorPE']
         trade_history = literal_eval(STR_TO_NUM(TRADE_HISTORY(text)[1]))
         trade_history = DataFrame(trade_history, columns=('date', 'pc', 'py', 'pmin', 'pmax', 'tno', 'tvol', 'tval'))
         trade_history['date'] = to_datetime(trade_history['date'], format='%Y%m%d')
         trade_history.set_index('date', inplace=True)
         return {
-            'tmax': float(t_min_max[2])
-            , 'tmin': float(t_min_max[1])
-            , 'bvol': int(BASE_VOLUME_SEARCH(text)[1])
-            , 'eps': int(eps_match[1]) if eps_match is not None else None
-            , 'free_float': int(
-                free_float_match[1]) if free_float_match is not None else None
-            , 'l30': title_match[1]
-            , 'sector_name': GROUP_NAME_SEARCH(text)[1]
-            , 'market': title_match[3]
-            , 'month_average_volume': int(MONTH_AVG_VOL_SEARCH(text)[1])
-            , 'l18': title_match[2]
-            , 'sector_pe': float(
-                sector_pe_match[1]) if sector_pe_match is not None else None
-            , 'z': int(SHARES_SEARCH(text)[1])
-            , 'week_max': float(wy_min_max[2])
-            , 'week_min': float(wy_min_max[1])
-            , 'year_max': float(wy_min_max[4])
-            , 'year_min': float(wy_min_max[3])
-            , 'related_companies': literal_eval(STR_TO_NUM(RELATED_COMPANIES(text)[1]))
-            , 'trade_history': trade_history
+            'bvol': int(m['BaseVol']),
+            'cisin': m['CIsin'],
+            'cs': int(m['CSecVal'].lstrip()),
+            'eps': int(eps) if eps else None,
+            'flow': int(m['Flow']),
+            'free_float': int(free_float) if free_float else None,
+            'group_code': m['CgrValCot'],
+            'isin': m['InstrumentID'],
+            'l18': m['LVal18AFC'],
+            'l30': title_match[1],
+            'market': title_match[2],
+            'month_average_volume': int(m['QTotTran5JAvg']),
+            'related_companies': literal_eval(STR_TO_NUM(RELATED_COMPANIES(text)[1])),
+            'sector_name': m['LSecVal'],
+            'sector_pe': float(sector_pe) if sector_pe else None,
+            'tmax': float(m['PSGelStaMax']),
+            'tmin': float(m['PSGelStaMin']),
+            'trade_history': trade_history,
+            'week_max': float(m['MaxWeek']),
+            'week_min': float(m['MinWeek']),
+            'year_max': float(m['MaxYear']),
+            'year_min': float(m['MinYear']),
+            'z': int(m['ZTitad']),
         }  # todo: add 'codal_data'
 
     def get_info(self, orders=True, index=False) -> dict:
@@ -145,7 +172,7 @@ class Instrument:
             , 'pmin': int(pmin), 'pmax': int(pmax)
             , 'tno': int(tno), 'tvol': int(tvol), 'tval': int(tval)}
         if index:
-            result |= parse_index(index_info)
+            result |= _parse_index(index_info)
         if nav:
             result['nav'] = int(nav)
             result['nav_datetime'] = jstrptime(nav_datetime, '%Y/%m/%d %H:%M:%S')
@@ -239,7 +266,7 @@ def get_market_watch_init(index=True) -> dict:
     # joined_df.index = to_numeric(joined_df.index, downcast='unsigned')
     result = {'dataframe': joined_df}
     if index:
-        result |= parse_index(index_data)
+        result |= _parse_index(index_data)
     return result
 
 
@@ -266,7 +293,7 @@ def get_closing_price_all() -> DataFrame:
         tsetmc filters. See:
             http://tsetmc.com/Site.aspx?ParTree=151715&LnkIdn=3197
     """
-    content = get_content('http://members.tsetmc.com/tsev2/data/ClosingPriceAll.aspx')
+    content = get_content('http://www.tsetmc.com/tsev2/data/ClosingPriceAll.aspx')
     data = _split_id_rows(content, id_row_len=11)
     df = DataFrame(data, columns=(
         'id', 'n', 'pc', 'pl', 'tno', 'tvol', 'tval'
@@ -308,7 +335,7 @@ def get_key_stats() -> DataFrame:
     return df
 
 
-def parse_index(s: str) -> dict:
+def _parse_index(s: str) -> dict:
     market_last_transaction, tse_status, tse_index, tse_index_change \
         , tse_value, tse_tvol, tse_tval, tse_tno \
         , otc_status, otc_tvol, otc_tval, otc_tno \
